/*
Copyright (©) 2003-2022 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
  
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


$(document).ready (function () {
  passageConnectToAll ();
});


function passageConnectToAll () {
  $ ('.starteditor').off ("click").on ("click", passageStartEditor);
}

function passageConnectToLast () {
  $ ('.starteditor:last').off ("click").on ("click", passageStartEditor);
}

function passageStartEditor (event) {
  event.preventDefault ();
  var a = $(this);
  var passage = a.attr ("passage");
  $.ajax ({
    url: "/edit/edit",
    type: "GET",
    data: { passage: passage },
    cache: false,
    success: function (response) {
      a.next ().html (response).fadeIn (100).delay (3000).fadeOut (1000);
    },
  });
}
